@@ -2,12 +2,11 @@
 #
 # @package      hubzero-submit-distributor
 # @file         monitorTunnel.py
-# @author       Steve Clark <clarks@purdue.edu>
-# @copyright    Copyright 2004-2011 Purdue University. All rights reserved.
+# @author       Steven Clark <clarks@purdue.edu>
+# @copyright    Copyright (c) 2004-2012 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2004-2011 Purdue University
-# All rights reserved.
+# Copyright (c) 2004-2012 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -25,7 +24,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-# HUBzero is a registered trademark of Purdue University.
+# HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
 # ----------------------------------------------------------------------
 #  monitorTunnel.py
@@ -40,9 +39,9 @@ import socket
 import time
 from errno import EINTR
 
-from LogMessage    import getLogMessageFileNo, openLog, logPID as log
-from TunnelsInfo   import TunnelsInfo
-from TunnelMonitor import TunnelMonitor
+from hubzero.submit.LogMessage    import getLogMessageFileNo, openLog, logPID as log
+from hubzero.submit.TunnelsInfo   import TunnelsInfo
+from hubzero.submit.TunnelMonitor import TunnelMonitor
 
 TUNNELMONITORHOST   = ""
 TUNNELMONITORPORT   = 5729
@@ -223,3 +222,4 @@ if __name__ == '__main__':
                                                  SSHIDENTITY)
    __monitorTunnel__.monitor()
 
+
